%global min_meson_ver 0.43.0
%global min_glib2_ver 2.46
%global min_jsonglib_ver 1.2
%global min_libsoup_ver 2.99.2
%global min_gtkdoc_ver 1.20
%global min_gi_ver 0.9.5
%global min_vala_ver 0.16

# Ensure that weird Provides aren't generated
%global __provides_exclude_from ^%{_qt6_qmldir}/Snapd/.*\\.so$

%define api           2
%define major         1

%define libname       %mklibname snapd-glib_ %{api} %{major}
%define girname       %mklibname snapd-glib-gir %{api}
%define develname     %mklibname snapd-glib -d

%define libsnapd_qt   %mklibname snapd-qt_ %{api} %{major}
%define libsnapd_qt_d %mklibname snapd-qt -d

Name:		snapd-glib
Version:	1.70
Release:	%mkrel 1
Summary:	Library providing a GLib interface to snapd
Group:		System/Libraries
License:	LGPL-2.0-only OR LGPL-3.0-only
URL:		https://github.com/canonical/snapd-glib
Source0:	https://github.com/canonical/snapd-glib/releases/download/%{version}/%{name}-%{version}.tar.gz

# Backports from upstream

BuildRequires:	gtk-doc >= %{min_gtkdoc_ver}
BuildRequires:	meson >= %{min_meson_ver}
BuildRequires:	gettext
BuildRequires:	vala >= %{min_vala_ver}
BuildRequires:	python3dist(gi-docgen)
BuildRequires:	pkgconfig(gobject-introspection-1.0) >= %{min_gi_ver}
BuildRequires:	pkgconfig(gio-2.0) >= %{min_glib2_ver}
BuildRequires:	pkgconfig(gio-unix-2.0) >= %{min_glib2_ver}
BuildRequires:	pkgconfig(glib-2.0) >= %{min_glib2_ver}
BuildRequires:	pkgconfig(json-glib-1.0) >= %{min_jsonglib_ver}
BuildRequires:	pkgconfig(libsoup-3.0) >= %{min_libsoup_ver}
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Help)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6Qml)


%description
%{name} is a library that provides an interface to communicate
with snapd for GLib based applications.

%package -n %{libname}
Summary:	Library providing a GLib interface to snapd
Group:		System/Libraries

%description -n %{libname}
%{name} is a library that provides an interface to communicate
with snapd for GLib based applications.

%package -n	%{girname}
Summary:	GObject Introspection interface description for Snapd
Group:		System/Libraries
Requires:	%{libname} = %{version}-%{release}

%description -n	%{girname}
GObject Introspection interface description for Snapd.

%package -n %{develname}
Summary:        Development files for %{name}
Group:		Development/C++
Requires:	%{libname}%{?_isa} = %{version}-%{release}
Requires:	%{girname}%{?_isa} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
This package provides the files for developing applications
that use %{name} to communicate with snapd.


%package -n %{libsnapd_qt}
Summary:	Library providing a Qt6 interface to snapd
Group:		System/Libraries
Requires:	qt6-qml-snapd >= %{version}-%{release}

%description -n %{libsnapd_qt}
snapd-qt is a library that provides an interface to communicate
with snapd for Qt based applications.

%package -n qt6-qml-snapd
Summary:	Library providing a Qt6 QML interface to snapd
Group:		Graphical desktop/KDE

%description -n qt6-qml-snapd
snapd-qt-qml is a library that provides an interface to communicate
with snapd for Qt QML based applications.

%package -n %{libsnapd_qt_d}
Summary:	Development files for snapd-qt
Group:		Development/KDE and Qt
Requires:	%{libsnapd_qt}%{?_isa} = %{version}-%{release}
Requires:	%{develname} = %{version}-%{release}
Provides:	snapd-qt-devel = %{version}-%{release}

%description -n %{libsnapd_qt_d}
This package provides the files for developing applications
that use snapd-qt to communicate with snapd.


%prep
%autosetup -p1


%build
%meson -D tests=false
%meson_build


%install
%meson_install


%files -n %{libname}
%license COPYING.LGPL2 COPYING.LGPL3
%doc NEWS
%{_libdir}/libsnapd-glib-%{api}.so.%{major}{,.*}

%files -n %{girname}
%{_libdir}/girepository-1.0/Snapd-%{api}.typelib

%files -n %{develname}
%doc %{_docdir}/snapd-glib/
%{_includedir}/snapd-glib-%{api}/
%{_libdir}/libsnapd-glib-%{api}.so
%{_libdir}/pkgconfig/snapd-glib-%{api}.pc
%{_datadir}/vala/vapi/snapd-glib-%{api}.*
%{_datadir}/gir-1.0/Snapd-%{api}.gir

%files -n %{libsnapd_qt}
%license COPYING.LGPL2 COPYING.LGPL3
%{_libdir}/libsnapd-qt-%{api}.so.%{major}{,.*}

%files -n qt6-qml-snapd
%{_qt6_qmldir}/Snapd%{api}/

%files -n %{libsnapd_qt_d}
%{_includedir}/snapd-qt-%{api}/
%{_libdir}/libsnapd-qt-%{api}.so
%{_libdir}/pkgconfig/snapd-qt-%{api}.pc
%{_libdir}/cmake/Snapd%{api}/


%changelog
* Sat Jun 14 2025 daviddavid <daviddavid> 1.70-1.mga10
+ Revision: 2190949
- new version: 1.70

* Mon May 05 2025 daviddavid <daviddavid> 1.67-1.mga10
+ Revision: 2181184
- new version: 1.67

* Sat Jan 11 2025 daviddavid <daviddavid> 1.66-2.mga10
+ Revision: 2137590
- fix dependencies

* Sat Jan 11 2025 daviddavid <daviddavid> 1.66-1.mga10
+ Revision: 2137356
- initial package snapd-glib

